import { ResourceObject, ResourceObjectRelationships } from '@klerick/json-api-nestjs-shared';
import { JsonApiTransformerService, OrmService, PatchData, PatchRelationshipData, PostData, PostRelationshipData, Query, QueryOne } from '@klerick/json-api-nestjs';
import { MicroOrmUtilService } from './micro-orm-util.service';
import { RelationKeys } from '@klerick/json-api-nestjs-shared';
export declare class MicroOrmService<E extends object, IdKey extends string = 'id'> implements OrmService<E, IdKey> {
    microOrmUtilService: MicroOrmUtilService<E, IdKey>;
    jsonApiTransformerService: JsonApiTransformerService<E, IdKey>;
    getAll(query: Query<E, IdKey>): Promise<ResourceObject<E, 'array', null, IdKey>>;
    getOne(id: number | string, query: QueryOne<E, IdKey>): Promise<ResourceObject<E, 'object', null, IdKey>>;
    deleteOne(id: number | string): Promise<void>;
    postOne(inputData: PostData<E, IdKey>): Promise<ResourceObject<E, 'object', null, IdKey>>;
    patchOne(id: number | string, inputData: PatchData<E, IdKey>): Promise<ResourceObject<E, 'object', null, IdKey>>;
    getRelationship<Rel extends RelationKeys<E, IdKey>>(id: number | string, rel: Rel): Promise<ResourceObjectRelationships<E, IdKey, Rel>>;
    deleteRelationship<Rel extends RelationKeys<E, IdKey>>(id: number | string, rel: Rel, input: PostRelationshipData): Promise<void>;
    postRelationship<Rel extends RelationKeys<E, IdKey>>(id: number | string, rel: Rel, input: PostRelationshipData): Promise<ResourceObjectRelationships<E, IdKey, Rel>>;
    patchRelationship<Rel extends RelationKeys<E, IdKey>>(id: number | string, rel: Rel, input: PatchRelationshipData): Promise<ResourceObjectRelationships<E, IdKey, Rel>>;
}
