"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MikroOrmFormatErrorService = void 0;
const tslib_1 = require("tslib");
const json_api_nestjs_1 = require("@klerick/json-api-nestjs");
const common_1 = require("@nestjs/common");
const core_1 = require("@mikro-orm/core");
const constants_1 = require("../constants");
const duplicateItems = (errorText, options, detail) => {
    errorText = 'Duplicate value';
    if (detail) {
        const matches = detail.match(/(?<=\().+?(?=\))/gm);
        if (matches) {
            errorText = `Duplicate value in the "${matches[0]}"`;
        }
    }
    const error = {
        code: 'invalid_arguments',
        message: errorText,
        path: ['data', 'attributes'],
    };
    return new common_1.ConflictException([error], options);
};
class MikroOrmFormatErrorService extends json_api_nestjs_1.ErrorFormatService {
    constructor() {
        super(...arguments);
        this.errorMsg = 'Internal Server Error';
    }
    formatError(error) {
        try {
            if (error instanceof core_1.ValidationError) {
                return this.formatValidationError(error);
            }
            if (error instanceof core_1.DriverException) {
                return this.prepareDataBaseError(error);
            }
            return super.formatError(error);
        }
        catch (error) {
            return super.formatError(error);
        }
    }
    formatValidationError(error) {
        const { message } = error;
        const entity = error.getEntity();
        const errorObject = {
            code: 'invalid_arguments',
            message: message.split('\n').at(0) || message,
            path: [],
        };
        if (entity) {
            errorObject['path'] = ['data', 'attributes'];
        }
        const descriptionOrOptions = this.mainConfig.options
            .debug
            ? { cause: error }
            : {};
        return new common_1.BadRequestException([errorObject], descriptionOrOptions);
    }
    prepareDataBaseError(error) {
        if (!this.em
            .getPlatform()
            .getConfig()
            .getDriver()
            .constructor.name.startsWith('Postgre')) {
            return super.formatError(error);
        }
        const { errorCode, errorMsg, detail, table } = {
            errorCode: error.code,
            errorMsg: error.message,
            detail: Reflect.get(error, 'detail'),
            table: Reflect.get(error, 'table'),
        };
        const descriptionOrOptions = this.mainConfig.options
            .debug
            ? { cause: error }
            : {};
        switch (error.constructor) {
            case core_1.UniqueConstraintViolationException:
                return duplicateItems(errorMsg, descriptionOrOptions, detail);
            default:
                return super.formatError(error);
        }
    }
}
exports.MikroOrmFormatErrorService = MikroOrmFormatErrorService;
tslib_1.__decorate([
    (0, common_1.Inject)(constants_1.CURRENT_ENTITY_MANAGER_TOKEN),
    tslib_1.__metadata("design:type", core_1.EntityManager)
], MikroOrmFormatErrorService.prototype, "em", void 0);
tslib_1.__decorate([
    (0, common_1.Inject)(json_api_nestjs_1.MODULE_OPTIONS_TOKEN),
    tslib_1.__metadata("design:type", Object)
], MikroOrmFormatErrorService.prototype, "mainConfig", void 0);
//# sourceMappingURL=mikro-orm-format.error.service.js.map